==> sife-0.0.11.tgz: package/styleguide/js/components.js <==
/* global $ */
$(function() {

	var app = {

		currentIframeSize: 'xs',

		initialize: function() {

			var self = this;
			this.renderComponentList();

			$('.js-component-list').delegate('a', 'click', function(e) {

				e.preventDefault();

				$('.js-component-list').find('li').removeClass('pure-menu-selected');
				$(e.currentTarget).parent('li').addClass('pure-menu-selected');

				self.currentComponentName = $(e.currentTarget).attr('data-component');
				self.loadComponent(self.currentComponentName);

			});

			$('.js-size-menu-link').on('click', function(e) {

				e.preventDefault();

				$('.js-size-menu-link').parent('li').removeClass('pure-menu-selected');
				$(e.currentTarget).parent('li').addClass('pure-menu-selected');

				var size = $(e.currentTarget).attr('data-size');

				$('.js-iframe')
					.removeClass('iframe-size-xs iframe-size-s iframe-size-m iframe-size-l iframe-size-full')
					.addClass('iframe-size-' + size);

				self.currentIframeSize = size;

			});

			$('.js-config-panel').delegate('select[name="data"]', 'change', function(e) {
				self.loadIframe(self.currentComponentName, $(e.currentTarget).val());
			});

		},

		loadComponent: function(componentName) {

			// load iframe
			this.loadIframe(componentName, 'standard.json');

			//load all data available
			$.getJSON('/component-datas/' + componentName, function(resp) {

				var select = '<select name="data">';

				for (var i = 0; i < resp.length; i++) {
					select += '<option ' + (resp[i] === 'standard.json' ? 'selected' : '') + '>' + resp[i] + '</option>';
				}

				select+='</select>';

				$('.js-config-panel').html('Data: ' + select);

			});

		},

		loadIframe: function(componentName, data) {
			$('.js-content-target').html('<iframe src="component.html?' + componentName + '#' + data + '" frameborder="0" class="u-l-full js-iframe iframe iframe-size-' + this.currentIframeSize + '"></iframe>');
		},

		renderComponentList: function() {

			var lis = [];

			for (var tplKey in window.Handlebars.partials) {

				if (tplKey.match(/-wrapper$/)) continue;

				if (tplKey.match(/^Theme-/)) continue;
				lis.push('<li class="pure-menu-item"><a href="#" class="pure-menu-link" data-component="' + tplKey + '">' + tplKey + '</a></li>');

			}

			$('.js-component-list').html(lis.join(''));

		}
	};

	app.initialize();

});

==> sife-0.0.43.tgz: package/styleguide/js/components.js <==
/* global $ */
$(function() {

	var app = {

		currentIframeSize: 'xs',

		initialize: function() {

			var self = this;
			this.renderComponentList();

			$('.js-component-list').delegate('a', 'click', function(e) {

				e.preventDefault();

				$('.js-component-list').find('li').removeClass('pure-menu-selected');
				$(e.currentTarget).parent('li').addClass('pure-menu-selected');

				self.currentComponentName = $(e.currentTarget).attr('data-component');
				self.loadComponent(self.currentComponentName);

			});

			$('.js-size-menu-link').on('click', function(e) {

				e.preventDefault();

				$('.js-size-menu-link').parent('li').removeClass('pure-menu-selected');
				$(e.currentTarget).parent('li').addClass('pure-menu-selected');

				var size = $(e.currentTarget).attr('data-size');

				$('.js-iframe')
					.removeClass('iframe-size-xs iframe-size-s iframe-size-m iframe-size-l iframe-size-full')
					.addClass('iframe-size-' + size);

				self.currentIframeSize = size;

			});

			$('.js-config-panel').delegate('select[name="data"]', 'change', function(e) {
				self.loadIframe(self.currentComponentName, $(e.currentTarget).val());
			});

			$('.js-content-target').css('height', $('.js-content-target').height()-$('.skin-topbar').height());

			$('.js-component-list-filter-field').on('keyup', function(){
				var val = $(this).val();
				self.filterComponentList(val);
			});

		},

		filterComponentList: function(filterString){
			filterString = filterString.toLowerCase();
			if(filterString===''){
				$('.js-component-list').find('li').removeClass('u-hide');
			}
			$('.js-component-list').find('li').each(function(){
				$(this).toggleClass('u-hide', $(this.firstChild).data('component').toLowerCase().indexOf(filterString)===-1);
			});
		},

		loadComponent: function(componentName) {

			// load iframe
			this.loadIframe(componentName, '');

			//load all data available
			$.getJSON('/component-datas/' + componentName, function(resp) {

				var select = '<select name="data"><option value="" selected>All</option>';

				for (var i = 0; i < resp.length; i++) {
					select += '<option>' + resp[i].replace('.json', '') + '</option>';
				}

				select+='</select>';

				$('.js-config-panel').html('Data: ' + select);

			});

		},

		loadIframe: function(componentName, data) {
			$('.js-content-target').html('<iframe src="component.html?' + componentName + '#' + data + '" frameborder="0" class="u-l-full js-iframe iframe iframe-size-' + this.currentIframeSize + '"></iframe>');
		},

		renderComponentList: function() {

			var lis = [];

			for (var tplKey in window.Handlebars.partials) {

				if (tplKey.match(/-wrapper$/)) continue;

				if (tplKey.match(/^Theme-/)) continue;
				lis.push('<li class="pure-menu-item"><a href="#" class="pure-menu-link" data-component="' + tplKey + '">' + tplKey + '</a></li>');

			}

			$('.js-component-list').html(lis.join(''));

		}
	};

	app.initialize();

});
